// MultMultiDocTemplate.cpp: implementation of the CMultMultiDocTemplate class.
//
//////////////////////////////////////////////////////////////////////

/*

	author:			Babak Taati ( http://qlink.queensu.ca/~3bt1/ )
	Download link:	http://qlink.queensu.ca/~3bt1/Miscellaneous/Downloads.htm	

	Description:	This is a simple project that allows opening / saving multiple types of documents
  
	References: 	1. MFC Document/View documentation and enhancements, by Roger Allen on CodeProject.com
					2. How to support two file extensions per MFC document type, Micorosft support document Article ID 141921
					3. DocMgrEx.exe Assoc Multiple File Extension w/2 Doc Tyle, Micorosft support document Article ID 198538
					4. Selecting multiple files in File Open dialog, by Kaus Gutter on CodeGuru.com
					5. Opening multiple documents of several types at once, by Ernesto Perales Soto on CodeProject.com

	Date:			Nov 2004

*/

#include "stdafx.h"
#include "MyFirstProject.h"
#include "MultMultiDocTemplate.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CMultMultiDocTemplate::CMultMultiDocTemplate(UINT nIDResource, CRuntimeClass *pDocClass, CRuntimeClass *pFrameClass, CRuntimeClass *pViewClass)

: CMultiDocTemplate(nIDResource, pDocClass, pFrameClass, pViewClass)

{

}




CMultMultiDocTemplate::~CMultMultiDocTemplate()
{

}



BOOL CMultMultiDocTemplate::GetDocString(CString& rString, enum DocStringIndex i) const
{
	CString strTemp,strLeft,strRight;
    int nFindPos;
    AfxExtractSubString(strTemp, m_strDocStrings, (int)i);

    if(i == CDocTemplate::filterExt)  {
      nFindPos=strTemp.Find(';');
      if(-1 != nFindPos) {
        //string contains two extensions
        strLeft=strTemp.Left(nFindPos+1);
        strRight="*"+strTemp.Right(lstrlen((const
        char*)strTemp)-nFindPos-1);
        strTemp=strLeft+strRight;
      }
    }
    
	rString = strTemp;
    
	return TRUE;

}


CDocTemplate::Confidence CMultMultiDocTemplate::MatchDocType(const char* pszPathName, CDocument*& rpDocMatch)
{
     ASSERT(pszPathName != NULL);
     rpDocMatch = NULL;

     // go through all documents
     POSITION pos = GetFirstDocPosition();
     while (pos != NULL)
     {
        CDocument* pDoc = GetNextDoc(pos);
        if (pDoc->GetPathName() == pszPathName) {
           // already open
           rpDocMatch = pDoc;
           return yesAlreadyOpen;
        }
     }  // end while

     // see if it matches either suffix
     CString strFilterExt;
     if (GetDocString(strFilterExt, CDocTemplate::filterExt) && !strFilterExt.IsEmpty())
     {
        // see if extension matches
        ASSERT(strFilterExt[0] == '.');
        CString ext1,ext2;
        int nDot = CString(pszPathName).ReverseFind('.');
        const char* pszDot = nDot < 0 ? NULL : pszPathName + nDot;

		int nSemi = strFilterExt.Find(';');
        if(-1 != nSemi)   {
          // string contains two extensions
          ext1=strFilterExt.Left(nSemi);
          ext2=strFilterExt.Mid(nSemi+2);
          // check for a match against either extension
          if (nDot >= 0 && (lstrcmpi(pszPathName+nDot, ext1) == 0
              || lstrcmpi(pszPathName+nDot,ext2) ==0))
            return yesAttemptNative; // extension matches
        }
        else
        { // string contains a single extension
          if (nDot >= 0 && (lstrcmpi(pszPathName+nDot, strFilterExt)==0))
             return yesAttemptNative;  // extension matches
		  }
        }
	return yesAttemptForeign; //unknown document type
}




